Module generated

Module generated 

Modules

wasm_sql

Structs

Host_
Auto-generated bindings for an instance a component which implements the world host.
Host_Indices
Auto-generated bindings for index of the exports of host.
Host_Pre
Auto-generated bindings for a pre-instantiated version of a component which implements the world host.